﻿using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using UserMicroservice.Models;
using UserMicroservice.Services;

namespace UserMicroservice.Controllers
{
    [ApiController]
    [Route("api/[controller]")]
    public class UsersController : ControllerBase
    {
        // Dependency injection of a user service
        private readonly IUserService _userService;

        public UsersController(IUserService userService)
        {
            _userService = userService;
        }

        // POST: api/Users/register
        [HttpPost("register")]
        public IActionResult Register([FromBody] RegisterModel model)
        {
            string token = _userService.RegisterUser(model.Email, model.Password);
            if(token == null)
                return BadRequest();

            return Ok(token);
            //return Created("api/users/{id}", new { /* user data */ });
        }

        // POST: api/Users/login
        [HttpPost("login")]
        public IActionResult Login([FromBody] LoginModel model)
        {
            string? token = _userService.Login(model.Email, model.Password);
            if (string.IsNullOrEmpty(token))
                return Unauthorized();
            
            return Ok(token);
        }

        // GET: api/Users
        [Authorize]
        [HttpGet()]
        public IActionResult GetUsers()
        {
           List<User> users = new List<User>()
           {
               new User("User1", "Password1"),
               new User("User2", "Password2"),
               new User("User3", "Password3")
           };

            return Ok(users);
        }

        // GET: api/Users/{id}
        [Authorize]
        [HttpGet("{id}")]
        public IActionResult GetUser(int id)
        {
            return Ok(new User( /* user data */ ));
        }

        // PUT: api/Users/{id}
        [Authorize]
        [HttpPut("{id}")]
        public IActionResult UpdateUser(int id, [FromBody] User user)
        {
            return Ok(user);
        }
    }
}
